<?php

function admin_scripts() {  
	wp_enqueue_media();
	wp_enqueue_script( 'backend-mediaselector', get_template_directory_uri() . '/js/mediaselector.js', array(), '20210407', true );
}

add_action('admin_enqueue_scripts', 'admin_scripts');

function remove_meta_boxes() {
    remove_meta_box('postcustom', 'beispiel', 'core');
    remove_meta_box('commentsdiv', 'beispiel', 'core');
	remove_meta_box('postexcerpt', 'beispiel', 'core');
	remove_meta_box('trackbacksdiv', 'beispiel', 'core');
	remove_meta_box('commentstatusdiv', 'beispiel', 'core');	
}

add_action( 'admin_menu', 'remove_meta_boxes' );

function custom_post_type() {
	$labels = array(
		'name' => 'Beispiel Einträge',
		'singular_name' => 'Beispiel',
		'menu_name' => 'Beispiel',
		'parent_item_colon' => '',
		'all_items' => 'Alle Einträge',
		'view_item' => 'Eintrag ansehen',
		'add_new_item' => 'Neuer Eintrag',
		'add_new' => 'Hinzufügen',
		'edit_item' => 'Eintrag bearbeiten',
		'update_item' => 'Update Eintrag',
		'search_items' => '',
		'not_found' => '',
		'not_found_in_trash' => '',
	);
	
	$rewrite = array(
		'slug' => 'beispiel',
		'with_front' => true,
		'pages' => true,
		'feeds' => true,
	);
	
	$args = array(
		'labels' => $labels,
		'supports' => array( 'title', 'editor', 'excerpt', 'thumbnail', 'comments', 'trackbacks', ),
		'taxonomies' => array( 'category', 'post_tag' ),
		'hierarchical' => false,
		'public' => true,
		'show_ui' => true,
		'show_in_menu' => true,
		'show_in_nav_menus' => true,
		'show_in_admin_bar' => true,
		'menu_position' => 5,
		'can_export' => false,
		'has_archive' => true,
		'exclude_from_search' => false,
		'publicly_queryable' => true,
		'rewrite' => $rewrite,
		'capability_type' => 'page',
	);
	
	register_post_type( 'beispiel', $args );
}

add_action( 'init', 'custom_post_type', 0 );

function add_metabox() {
 
	add_meta_box(
		'sample_metabox', // metabox ID
		'Sample - Meta Box with Media Selector', // title
		'sample_metabox_callback', // callback function
		'beispiel', // post type or post types in array
		'side', // position (normal, side, advanced)
		'core' // priority (default, low, high, core)
	);
 
}

add_action( 'admin_menu', 'add_metabox' );

function sample_metabox_callback( $post ) {
	
	$image_url = esc_attr(get_post_meta( $post->ID, 'imagePath', true ));
	
	echo ' 
	<div>
		<button class="imgSelectorBtn" data-refinput="imagePath" data-refimage="image">Bild öffnen</button>
		<input type="text" id="imagePath" name="imagePath" value="' . $image_url . '" class="regular-text"/>
		<br/><br/>
		<img id="image" name="image" src="' . $image_url . '" width="500px" height="*"/>
	</div>
	';
	?>
	<script>
		var inputElement = '-undefined-';
		var imageElement = '-undefined-';

		jQuery( '.imgSelectorBtn' ).on( 'click', function( e ) {
			inputElement = jQuery(this).data("refinput");
			imageElement = jQuery(this).data("refimage");
			e.preventDefault();
			customMediaLibrary.open();
		});

		jQuery(function() {
			customMediaLibrary.on( 'select', function() {
				var selectionCollection = customMediaLibrary.state().get('selection').first().toJSON();
				jQuery('#'+inputElement).val(selectionCollection.url);
				jQuery('#'+imageElement).attr("src",selectionCollection.url);
			});
		});
	</script>
	<?php
}
 
function save_meta( $post_id, $post ) {
	$post_type = get_post_type_object( $post->post_type );
	 
	if ( ! current_user_can( $post_type->cap->edit_post, $post_id ) ) {
		return $post_id;
	}
 
	if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) {
		return $post_id;
	}
 
	if( $post->post_type != 'beispiel' ) {
		return $post_id;
	}
	
	error_log('do update');
		
	updateOrDeleteMeta($post_id, 'imagePath');
}

add_action( 'save_post', 'save_meta',10,3 );

function updateOrDeleteMeta($post_id, $metatag){
		
	if( isset( $_POST[ $metatag ] ) ) {
		$field = sanitize_text_field( $_POST[ $metatag ] );
		
		error_log($field);
		
		update_post_meta( $post_id, $metatag, sanitize_text_field( $_POST[ $metatag ] ) );
	} else {
		delete_post_meta( $post_id, $metatag );
	}	
}

?>